==> insighttoolkit4_4.2.1.orig.tar.xz: InsightToolkit-4.2.1/Modules/Core/Common/include/itkSimpleDataObjectDecorator.h <==
/*=========================================================================
 *
 *  Copyright Insight Software Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
/*=========================================================================
 *
 *  Portions of this file are subject to the VTK Toolkit Version 3 copyright.
 *
 *  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 *
 *  For complete copyright, license and disclaimer of warranty information
 *  please refer to the NOTICE file at the top of the ITK source tree.
 *
 *=========================================================================*/
#ifndef __itkSimpleDataObjectDecorator_h
#define __itkSimpleDataObjectDecorator_h

#include "itkDataObject.h"
#include "itkObjectFactory.h"

namespace itk
{
/** \class SimpleDataObjectDecorator
 * \brief Decorates any "simple" data type (data types without smart pointers) with a DataObject API
 *
 * SimpleDataObjectDecorator decorates an object with a DataObject
 * API. This allows simple objects to be encapsulated into objects
 * that can be passed as down the pipeline. This decorator is intended
 * to be used on native types (float, int, etc.) or any objects not
 * derived from itkObject.  To decorate a subclass of itkObject, see
 * DataObjectDecorator.
 *
 * The decorator provides two methods Set() and Get() to access the
 * decorated object (referred internally as the component).
 *
 * Note that when an instance of SimpleDataObjectDecorator is created,
 * the component is initialized with its default constructor.
 *
 * SimpleDataObjectDecorator can decorate any simple data type. Two
 * other decorators are provided for decorating pointers.
 * DataObjectDecorator will decorate pointers to subclasses of
 * itkObject (internally storing the pointer in a
 * SmartPointer). AutoPointerDataObjectDecorator will decorate any
 * other pointer and manage the memory deallocationg of the component.
 *
 * \sa DataObjectDecorator
 * \sa AutoPointerDataObjectDecorator
 * \ingroup ITKSystemObjects
 *
 * \ingroup ITKCommon
 */
template< class T >
class ITK_EXPORT SimpleDataObjectDecorator:public DataObject
{
public:
  /** Standard typedefs. */
  typedef SimpleDataObjectDecorator  Self;
  typedef DataObject                 Superclass;
  typedef SmartPointer< Self >       Pointer;
  typedef SmartPointer< const Self > ConstPointer;

  /** Typedef for the component type (object being decorated) */
  typedef T ComponentType;

  /** Method for creation through the object factory. */
  itkNewMacro(Self);

  /** Run-time type information (and related methods). */
  itkTypeMacro(SimpleDataObjectDecorator, DataObject);

  /** Set the contained object */
  virtual void Set(const T & val);

  /** Get the contained object */
  virtual T &       Get() { return m_Component; }
  virtual const T & Get() const { return m_Component; }
protected:
  SimpleDataObjectDecorator();
  ~SimpleDataObjectDecorator();
  virtual void PrintSelf(std::ostream & os, Indent indent) const;

protected:
private:
  SimpleDataObjectDecorator(const Self &); //purposely not implemented
  void operator=(const Self &);            //purposely not implemented

  ComponentType m_Component;
  bool          m_Initialized;
};
} // end namespace itk

// Define instantiation macro for this template.
#define ITK_TEMPLATE_SimpleDataObjectDecorator(_, EXPORT, TypeX, TypeY)     \
  namespace itk                                                             \
  {                                                                         \
  _( 1 ( class EXPORT SimpleDataObjectDecorator< ITK_TEMPLATE_1 TypeX > ) ) \
  namespace Templates                                                       \
  {                                                                         \
  typedef SimpleDataObjectDecorator< ITK_TEMPLATE_1 TypeX >                 \
  SimpleDataObjectDecorator##TypeY;                                       \
  }                                                                         \
  }

#if ITK_TEMPLATE_EXPLICIT
#include "Templates/itkSimpleDataObjectDecorator+-.h"
#endif

#if ITK_TEMPLATE_TXX
#include "itkSimpleDataObjectDecorator.hxx"
#endif

#endif

==> insighttoolkit4_4.3.1.orig.tar.xz: InsightToolkit-4.3.1/Modules/Core/Common/include/itkSimpleDataObjectDecorator.h <==
/*=========================================================================
 *
 *  Copyright Insight Software Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/
/*=========================================================================
 *
 *  Portions of this file are subject to the VTK Toolkit Version 3 copyright.
 *
 *  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 *
 *  For complete copyright, license and disclaimer of warranty information
 *  please refer to the NOTICE file at the top of the ITK source tree.
 *
 *=========================================================================*/
#ifndef __itkSimpleDataObjectDecorator_h
#define __itkSimpleDataObjectDecorator_h

#include "itkDataObject.h"
#include "itkObjectFactory.h"

namespace itk
{
/** \class SimpleDataObjectDecorator
 * \brief Decorates any "simple" data type (data types without smart pointers) with a DataObject API
 *
 * SimpleDataObjectDecorator decorates an object with a DataObject
 * API. This allows simple objects to be encapsulated into objects
 * that can be passed as down the pipeline. This decorator is intended
 * to be used on native types (float, int, etc.) or any objects not
 * derived from itkObject.  To decorate a subclass of itkObject, see
 * DataObjectDecorator.
 *
 * The decorator provides two methods Set() and Get() to access the
 * decorated object (referred internally as the component).
 *
 * Note that when an instance of SimpleDataObjectDecorator is created,
 * the component is initialized with its default constructor.
 *
 * SimpleDataObjectDecorator can decorate any simple data type. Two
 * other decorators are provided for decorating pointers.
 * DataObjectDecorator will decorate pointers to subclasses of
 * itkObject (internally storing the pointer in a
 * SmartPointer). AutoPointerDataObjectDecorator will decorate any
 * other pointer and manage the memory deallocationg of the component.
 *
 * \sa DataObjectDecorator
 * \sa AutoPointerDataObjectDecorator
 * \ingroup ITKSystemObjects
 *
 * \ingroup ITKCommon
 */
template< class T >
class ITK_EXPORT SimpleDataObjectDecorator:public DataObject
{
public:
  /** Standard typedefs. */
  typedef SimpleDataObjectDecorator  Self;
  typedef DataObject                 Superclass;
  typedef SmartPointer< Self >       Pointer;
  typedef SmartPointer< const Self > ConstPointer;

  /** Typedef for the component type (object being decorated) */
  typedef T ComponentType;

  /** Method for creation through the object factory. */
  itkNewMacro(Self);

  /** Run-time type information (and related methods). */
  itkTypeMacro(SimpleDataObjectDecorator, DataObject);

  /** Set the contained object */
  virtual void Set(const T & val);

  /** Get the contained object */
  virtual T &       Get() { return m_Component; }
  virtual const T & Get() const { return m_Component; }

protected:
  SimpleDataObjectDecorator();
  ~SimpleDataObjectDecorator();
  virtual void PrintSelf(std::ostream & os, Indent indent) const;

protected:

private:
  SimpleDataObjectDecorator(const Self &); //purposely not implemented
  void operator=(const Self &);            //purposely not implemented

  ComponentType m_Component;
  bool          m_Initialized;
};
} // end namespace itk

#ifndef ITK_MANUAL_INSTANTIATION
#include "itkSimpleDataObjectDecorator.hxx"
#endif

#endif
